__author__ = "Fabio Caccamo"
__copyright__ = "Copyright (c) 2020-present Fabio Caccamo"
__description__ = "high-level file-system operations for lazy devs."
__email__ = "fabio.caccamo@gmail.com"
__license__ = "MIT"
__title__ = "python-fsutil"
__version__ = "0.9.1"
